from Models.AbstractSyntaxTree.RuntimeAbstractSyntaxTree import RuntimeAbstractSyntaxTree
from Models.Interpreter.Booleans import Booleans
from Models.Interpreter.FormatCharacters import FormatCharacters
from Models.Interpreter.Keywords import Keywords
from Models.Interpreter.Types import Types


class Repo:

    def __init__(self) -> None:
        self.debug = True

        # interpreter
        self.keywords = [
            # define keywords
            Keywords.Library,
            Keywords.Class,
            Keywords.Function,
            Keywords.Variable,
            Keywords.Use,
            Keywords.From,
            # builtin functions
            Keywords.Output,
            Keywords.Input,
            Keywords.Length,
            Keywords.Range,
            Keywords.Exit,
            # normal keywords
            Keywords.If,
            Keywords.ElseIf,
            Keywords.Else,
            Keywords.Pass,
            Keywords.If,
            Keywords.Return,
            # loops
            Keywords.While,
            Keywords.For,
            # access
            Keywords.Public
        ]
        self.types = [
            Types.strings.value[Types.Any.value],
            Types.strings.value[Types.Number.value],
            Types.strings.value[Types.String.value],
            Types.strings.value[Types.Bool.value],
            Types.strings.value[Types.List.value],
            Types.strings.value[Types.Dict.value],
            Types.strings.value[Types.Empty.value],
            Types.strings.value[Types.Void.value]
        ]
        self.format_chars = [
            FormatCharacters.chars.value[FormatCharacters.Left_Brace.value],
            FormatCharacters.chars.value[FormatCharacters.Right_Brace.value],
            FormatCharacters.chars.value[FormatCharacters.Left_Parenthesis.value],
            FormatCharacters.chars.value[FormatCharacters.Right_Parenthesis.value],
            FormatCharacters.chars.value[FormatCharacters.Left_Bracket.value],
            FormatCharacters.chars.value[FormatCharacters.Right_Bracket.value],
            FormatCharacters.chars.value[FormatCharacters.Semicolon.value],
            FormatCharacters.chars.value[FormatCharacters.Colon.value],
            FormatCharacters.chars.value[FormatCharacters.Comma.value],
            FormatCharacters.chars.value[FormatCharacters.Point.value]
        ]
        self.expr_chars = ['+', '-', '*', '/', '=', '^']
        self.bool_expr_chars = ['<', '>', '!', '!=', '==', '>=', '<=', '&&', '||']
        self.bool_values = [Booleans.Right, Booleans.Wrong]

        # runtime
        self.is_error = None
        self.AST: RuntimeAbstractSyntaxTree = RuntimeAbstractSyntaxTree()
